A function calculating the roots of a vectorized covariance matrix. The roots increasing, so square root for the first secondary diagonals, third root for the second secondary diagonal and so on. For roots with even order the absolute value of the argument is used, since the arguments can be negative.
subdiagonal_mean_ratio_cor(v, a, d)a transformed vector
vectorized correlation matrix which should be transformed
vector containing the indices which belong to the diagonal of the correlation matrix
dimension of the correlation matrix