A function which calculates the mean of the secondary diagonals and divide them through the next one. Since the elements can be negative, for the denominator absolute values are used.
subdiagonal_mean_ratio_fct(v, a, d)a transformed vector
vectorized covariance matrix which should be transformed
vector containing the indices which belong to the diagonal of the covariance matrix
dimension of the covariance matrix